'This VBS script will aid in the removal of the Uniprint Popup Client components
' and is used in tandem with a Windows Batch file that does some of the work.
'The Window Batch file has comments through to help understand what
' the individual steps are doing.
'
'This script will remove the Windows printer object and attempt to remove its 
' associated printer driver as well.  Once this script is finished it will call
' a Windows Batch file that goes through the steps of manually removing the Pharos
' Popup components. You can also do this manually by following the instructions
' in the below URL.
' https://pharos.custhelp.com/app/answers/detail/a_id/1520
'
'The 3 files you will need are:
' 1. This VBS script
' 2. The batch file and executable (CTskMstr.exe) included with the zip file.
'
'All sections of the script below are commented and all of the WScript.Echo lines have
' commented out but can be uncommented for additional debugging purposes.
'
'Written by:
' Jeff Geller jgeller@pharos.com
' Pharos Systems Technical Support
'
'Instructions:
' 1. Copy the 3 files into any directory on a client machine
' 2. Open an elevated command prompt and navigate to the directory you extracted the 3 files to
' 3. Run the command "cscript Remove-Popups.vbs" to execute the VBS script.
' -You can also use "wscript Remove-Popups.vbs"
' 4. This VBS script calls the batch file at the end

'Variables
Dim arrPrinterDriver(), arrPopupPrinters()
Dim numPrinters, PrinterFoundCount, Counter, HasPopupPrinter
Const HKEY_LOCAL_MACHINE = &H80000002
strComputer = "."
PrinterFoundCount = 0

'Section 1 -- Determine if the OS is 32-bit or 64-bit and set the registry key appropriately
Set WshShell = CreateObject("WScript.Shell")
OsType = WshShell.RegRead("HKLM\SYSTEM\CurrentControlSet\Control\Session Manager\Environment\PROCESSOR_ARCHITECTURE")
If OsType = "x86" Then
	wscript.echo "Windows 32bit system detected"
	strKeyPath = "SOFTWARE\Pharos\Popup Client\LocalPrinters"
ElseIf OsType = "AMD64" Then
	wscript.echo "Windows 64bit system detected"
	strKeyPath = "SOFTWARE\Wow6432Node\Pharos\Popup Client\LocalPrinters"
End If
Set objType = Nothing

'Section 2 -- First obtain the names of the Popup Printers installed from the registry
Set oReg=GetObject("winmgmts:{impersonationLevel=impersonate}!\\" & strComputer & "\root\default:StdRegProv")
oReg.EnumKey HKEY_LOCAL_MACHINE, strKeyPath, arrPopupPrinters

'Section 3 -- Check if we found any Pharos printer - If YES then count the number and set Found to 1
For Each subkey In arrPopupPrinters
    If (IsNull( arrSubKeys ) = false) Then
		'WScript.Echo "Printer " & subkey & " Found"
		HasPopupPrinter = 1
	End If
Next

'Section 4 -- If we found Popup printers ReDimension the array to hold data and set number found
If HasPopupPrinter <> 1 Then
	WScript.Echo "No Pharos Popup Printers Installed"
	WScript.Quit
Else
	numPrinters = UBound(arrPopupPrinters) + 1
	ReDim arrPrinterDriver(UBound(arrPopupPrinters))
	WScript.Echo "numPrinters:" & numPrinters
	For Counter = 0 to UBound(arrPopupPrinters)
		WScript.Echo "Found Pharos Popup Printer " & Counter & ":" & arrPopupPrinters(Counter)
	Next
End If

'Section 5 -- Enumerate all the printers on the local machine
Set objWMIService = GetObject("winmgmts:\\" & strComputer & "\root\cimv2")
Set colInstalledPrinters = objWMIService.ExecQuery ("Select * From Win32_Printer")

'Loop through the Pharos Popup printers found and delete them
For Each objPrinter in colInstalledPrinters
	'For each local printer found compare the printer name against the Popup Printer names we have in the Array
	For Counter = 0 to (numPrinters -1)
		WScript.Echo "Comparing printer " & Chr(34) & objPrinter.Name & Chr(34) & " to " & arrPopupPrinters(Counter)
		If (UCase(objPrinter.Name) = UCase(arrPopupPrinters(Counter))) Then	
			'Add the Driver Name into an Array variable to be deleted later
			WScript.Echo "Printer Queue " & arrPopupPrinters(Counter) & " uses driver " & Chr(34) & objPrinter.DriverName & Chr(34)	
			arrPrinterDriver(PrinterFoundCount) = objPrinter.DriverName
			WScript.Echo "Driver Array Item " & PrinterFoundCount & " contains " & arrPrinterDriver(PrinterFoundCount)
			'Delete the printer	
			objPrinter.Delete_
			WScript.Echo
			PrinterFoundCount = PrinterFoundCount + 1
		End If 
	Next 'End of Counter loop
Next 'End of objPrinter loop

'WScript.Echo "Done Searching..."

'Section 6 -- Sleep the script to allow the printer object to be deleted then delete the driver
'I have tried a few methods but this seems to be long enough to
'   allow the the drivers to be successfully deleted
WScript.Sleep 3000

'Section 7 -- Now using the Array we built delete the drivers the Popup Printers were using
for Counter = 0 to PrinterFoundCount - 1
	WScript.Echo "Deleting Driver " & arrPrinterDriver(Counter) & " used by a Pharos Printer"
	'Now we use printui.dll to delete the driver we found from the printer we deleted
	'Setup the shell object below to run
	Set objShell = Wscript.CreateObject("Wscript.Shell")
	objShell.Run("RUNDLL32 PRINTUI.DLL,PrintUIEntry /dd /q /m " & Chr(34) & arrPrinterDriver(Counter) & chr(34)),,false
	'Cleanup the shell object
	Set objShell = Nothing
Next

'Section 8 -- now execute the required batch file to remove the Popup components
dim shell
set shell=createobject("wscript.shell")
shell.run "RemovePopupComponents.bat"
set shell = Nothing